
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#ifndef AUTOAR_ENUM_TYPES_H
#define AUTOAR_ENUM_TYPES_H

#include <glib-object.h>

G_BEGIN_DECLS
/* Enumerations from "autoar-extractor.h" */
#define AUTOAR_TYPE_CONFLICT_ACTION (autoar_conflict_action_get_type ())
GType autoar_conflict_action_get_type (void) G_GNUC_CONST;
/* Enumerations from "autoar-format-filter.h" */
#define AUTOAR_TYPE_FORMAT (autoar_format_get_type ())
GType autoar_format_get_type (void) G_GNUC_CONST;
#define AUTOAR_TYPE_FILTER (autoar_filter_get_type ())
GType autoar_filter_get_type (void) G_GNUC_CONST;
G_END_DECLS

#endif /* AUTOAR_ENUM_TYPES_H */

/* Generated data ends here */

